@@ -1,5 +1,6 @@
-import os
-import json
+# import os
+# import sys
+# import json
 import time
 import re
 import random
@@ -18,10 +19,19 @@ class SearchPage:
 
     def __init__(self, domain):
         self.domain = re.sub(r"http://|https://|www.", "", domain)
+        # print(os.getcwd())
+        # print(sys.path)
         # self.search_box_file = os.getcwd().replace('\\', '/') + "/param/searchbox_of_searchpage.json"
-        self.search_box_file = "param/searchbox_of_searchpage.json"
-        with open(self.search_box_file, encoding='utf-8') as json_file:
-            self.search_box_dict = json.load(json_file)
+        # self.search_box_file = "param/searchbox_of_searchpage.json"
+        # with open(self.search_box_file, encoding='utf-8') as json_file:
+        #     self.search_box_dict = json.load(json_file)
+        self.search_box_dict = {'google.com': {'method': 'name', 'name': 'q'},
+                                'google.com.hk': {'method': 'name', 'name': 'q'},
+                                'baidu.com': {'method': 'name', 'name': 'wd'},
+                                'bing.com': {'method': 'name', 'name': 'q'},
+                                'cn.bing.com': {'method': 'name', 'name': 'q'},
+                                'sogou.com': {'method': 'name', 'name': 'query'},
+                                'weixin.sogou.com': {'method': 'name', 'name': 'query'}}
         self.search_method = self.search_box_dict.get(self.domain, {}).get('method')
         self.search_name = self.search_box_dict.get(self.domain, {}).get('name')
         self.driver = None
@@ -80,15 +90,29 @@ class IndexPage:
         self.driver.implicitly_wait(10)
         self.domain = urlparse(self.driver.current_url).netloc.replace('www.', '')
 
-        self.search_box_file = os.getcwd().replace('\\', '/') + '/param/searchbox_of_indexpage.json'
-        with open(self.search_box_file, encoding='utf-8') as file1:
-            self.search_box_dict = json.load(file1)
+        # self.search_box_file = os.getcwd().replace('\\', '/') + '/param/searchbox_of_indexpage.json'
+        # with open(self.search_box_file, encoding='utf-8') as file1:
+        #     self.search_box_dict = json.load(file1)
+        self.search_box_dict = {'google.com': {'method': 'name', 'name': 'q'},
+                                'google.com.hk': {'method': 'name', 'name': 'q'},
+                                'baidu.com': {'method': 'name', 'name': 'wd'},
+                                'bing.com': {'method': 'name', 'name': 'q'},
+                                'cn.bing.com': {'method': 'name', 'name': 'q'},
+                                'sogou.com': {'method': 'name', 'name': 'query'},
+                                'weixin.sogou.com': {'method': 'name', 'name': 'query'}}
         self.search_method = self.search_box_dict.get(self.domain, {}).get('method')
         self.search_name = self.search_box_dict.get(self.domain, {}).get('name')
 
-        self.search_result_file = os.getcwd().replace('\\', '/') + '/param/search_result.json'
-        with open(self.search_result_file, encoding='utf-8') as file2:
-            self.search_result_dict = json.load(file2)
+        # self.search_result_file = os.getcwd().replace('\\', '/') + '/param/search_result.json'
+        # with open(self.search_result_file, encoding='utf-8') as file2:
+        #     self.search_result_dict = json.load(file2)
+        self.search_result_dict = {'google.com': {'tag': 'div', 'class_name': 'g'},
+                                   'google.com.hk': {'tag': 'div', 'class_name': 'g'},
+                                   'baidu.com': {'tag': 'div', 'class_name': 'result c-container new-pmd'},
+                                   'bing.com': {'tag': 'li', 'class_name': 'b_algo'},
+                                   'cn.bing.com': {'tag': 'li', 'class_name': 'b_algo'},
+                                   'sogou.com': {'tag': 'div', 'class_name': 'vrwrap'},
+                                   'weixin.sogou.com': {'tag': 'div', 'class_name': 'txt-box'}}
         self.result_tag = self.search_result_dict.get(self.domain, {}).get('tag')
         self.result_class = self.search_result_dict.get(self.domain, {}).get('class_name')
 
